@@ -40,6 +40,9 @@ from yd_commands.config import (
 )
 from yd_commands.config_keys import *
 from yd_commands.mustache import (
+    LAZY_SUBS_WRAPPER,
+    TASK_GROUP_NUMBER_SUB,
+    TASK_NUMBER_SUB,
     load_json_file_with_mustache_substitutions,
     load_jsonnet_file_with_mustache_substitutions,
     load_toml_file_with_mustache_substitutions,
@@ -248,11 +251,12 @@ def create_task_group(
 
     # Name the Task Group
     num_task_groups = len(tasks_data[TASK_GROUPS])
-    task_group_name = check_str(
-        task_group_data.get(
-            NAME,
-            "task_group_" + str(tg_number + 1).zfill(len(str(num_task_groups))),
-        )
+    task_group_name = get_name(
+        task_group_data,
+        tg_number,
+        num_task_groups,
+        "task_group_",
+        TASK_GROUP_NUMBER_SUB,
     )
 
     # Assemble the RunSpecification values for the Task Group
@@ -265,6 +269,8 @@ def create_task_group(
     )
     if CONFIG_WR.task_type is not None and CONFIG_WR.task_type not in task_types:
         task_types.append(CONFIG_WR.task_type)
+    if len(task_types) == 0:
+        raise Exception(f"No Task Type(s) specified in Task Group '{task_group_name}'")
 
     vcpus_data: Optional[List[float]] = check_list(
         task_group_data.get(VCPUS, tasks_data.get(VCPUS, CONFIG_WR.vcpus))
@@ -417,11 +423,7 @@ def add_tasks_to_task_group(
         ):
             task_group_data = tasks_data[TASK_GROUPS][tg_number]
             task = tasks[task_number] if task_count is None else tasks[0]
-            task_name = check_str(
-                task.get(
-                    NAME, "task_" + str(task_number + 1).zfill(len(str(num_tasks)))
-                )
-            )
+            task_name = get_name(task, task_number, num_tasks, "task_", TASK_NUMBER_SUB)
             executable = check_str(
                 task.get(
                     EXECUTABLE,
@@ -657,6 +659,35 @@ def check_for_duplicates_in_file_lists(
         )
 
 
+def get_name(
+    entity_data: Dict,
+    entity_number: int,
+    num_entities: int,
+    name_prefix: str,
+    substitution_str: str,
+) -> str:
+    """
+    Create the name of an entity.
+    Supports lazy substitution.
+    """
+
+    def _entity_number_str():
+        return str(entity_number + 1).zfill(len(str(num_entities)))
+
+    try:
+        name = entity_data[NAME]
+        # Perform lazy substitutions
+        name = name.replace(
+            f"{LAZY_SUBS_WRAPPER}{substitution_str}"
+            f"{LAZY_SUBS_WRAPPER}",
+            _entity_number_str(),
+        )
+    except KeyError:
+        name = name_prefix + _entity_number_str()
+
+    return name
+
+
 def create_task(
     tasks_data: Dict,
     task_group_data: Dict,
